@@ -28,15 +28,45 @@ not_existing_attype = 'http://not.existing/type'
 tester_appname = 'http://not.existing/app'
 
 
+class TestMmifObject(unittest.TestCase):
+    
+    def test_setattr_additional_properties_disallowed(self):
+        """Test that setting additional properties raises AttributeError when disallowed"""
+        # Create an object that disallows additional properties
+        obj = MmifObject()
+        obj._unnamed_attributes = None  # Disallow additional properties
+        
+        with self.assertRaises(AttributeError) as cm:
+            obj.test_prop = "value"
+        self.assertIn("Additional properties are disallowed", str(cm.exception))
+    
+    def test_setattr_additional_properties_allowed(self):
+        """Test that setting additional properties works when allowed"""
+        obj = MmifObject()
+        obj._unnamed_attributes = {}  # Allow additional properties
+        
+        obj.test_prop = "value" 
+        self.assertEqual(obj.test_prop, "value")
+        self.assertEqual(obj._unnamed_attributes["test_prop"], "value")
+
+    def test_serialize_unnamed_attributes_none(self):
+        """Test serialization when _unnamed_attributes is None"""
+        obj = MmifObject()
+        obj._unnamed_attributes = None
+        
+        # This should not raise an error, but handle AttributeError gracefully
+        serialized = obj.serialize()
+        self.assertIsInstance(serialized, str)
+
+
 class TestMmif(unittest.TestCase):
 
     def setUp(self) -> None:
         self.mmif_examples_json = {k: json.loads(v) for k, v in MMIF_EXAMPLES.items()}
 
-    @pytest.mark.skip("comparing two `Mmif` objs with an arbitrary file path included won't work until https://github.com/seperman/deepdiff/issues/357 is addressed")
     def test_init_from_bytes(self):
-        mmif_from_str = Mmif(EVERYTHING_JSON)
-        mmif_from_bytes = Mmif(EVERYTHING_JSON.encode('utf8'))
+        mmif_from_str = Mmif(MMIF_EXAMPLES['everything'])
+        mmif_from_bytes = Mmif(MMIF_EXAMPLES['everything'].encode('utf8'))
         self.assertEqual(mmif_from_str, mmif_from_bytes)
 
     def test_str_mmif_deserialize(self):
@@ -456,10 +486,9 @@ class TestMmif(unittest.TestCase):
         except KeyError:
             self.fail("raised exception on duplicate ID add when overwrite was set to True")
     
-    @pytest.mark.skip("comparing two `Mmif` objs with an arbitrary file path included won't work until https://github.com/seperman/deepdiff/issues/357 is addressed")
     def test_eq_checking_order(self):
-        mmif1 = Mmif(EVERYTHING_JSON)
-        mmif2 = Mmif(EVERYTHING_JSON)
+        mmif1 = Mmif(MMIF_EXAMPLES['everything'])
+        mmif2 = Mmif(MMIF_EXAMPLES['everything'])
         view1 = View()
         view1.id = 'v99'
         view2 = View()
@@ -470,14 +499,68 @@ class TestMmif(unittest.TestCase):
         mmif2.add_view(view1)
         self.assertFalse(mmif1 == mmif2)
 
-        mmif3 = Mmif(EVERYTHING_JSON)
-        mmif4 = Mmif(EVERYTHING_JSON)
+        mmif3 = Mmif(MMIF_EXAMPLES['everything'])
+        mmif4 = Mmif(MMIF_EXAMPLES['everything'])
         mmif3.add_view(view1)
         mmif3.add_view(view2)
         mmif4.add_view(view1)
         mmif4.add_view(view2)
         self.assertTrue(mmif3 == mmif4)
 
+    def test_eq_basic(self):
+        """Test basic equality comparison (issue #311)"""
+        minimal_mmif = '''
+        {
+          "metadata": {
+            "mmif": "http://mmif.clams.ai/1.0.0"
+          },
+          "documents": [
+            {
+              "@type": "http://mmif.clams.ai/vocabulary/VideoDocument/v1",
+              "properties": {
+                "mime": "video",
+                "id": "d1",
+                "location": "file:///test.mp4"
+              }
+            }
+          ],
+          "views": []
+        }'''
+        m1 = Mmif(minimal_mmif)
+        m2 = Mmif(minimal_mmif)
+        self.assertTrue(m1 == m2)
+
+    def test_eq_with_different_documents(self):
+        """Test inequality when documents differ (issue #311)"""
+        mmif1_str = '''
+        {
+          "metadata": {"mmif": "http://mmif.clams.ai/1.0.0"},
+          "documents": [{"@type": "http://mmif.clams.ai/vocabulary/VideoDocument/v1",
+                         "properties": {"mime": "video", "id": "d1", "location": "file:///test1.mp4"}}],
+          "views": []
+        }'''
+        mmif2_str = mmif1_str.replace("d1", "d2")
+        m1 = Mmif(mmif1_str)
+        m2 = Mmif(mmif2_str)
+        self.assertFalse(m1 == m2)
+
+    def test_eq_ignores_contextual_attributes(self):
+        """Test that contextual attributes (timestamps) are ignored in equality comparison (issue #311)"""
+        from datetime import datetime, timedelta
+        mmif_str = '''
+        {
+          "metadata": {"mmif": "http://mmif.clams.ai/1.0.0"},
+          "documents": [{"@type": "http://mmif.clams.ai/vocabulary/VideoDocument/v1",
+                         "properties": {"mime": "video", "id": "d1", "location": "file:///test.mp4"}}],
+          "views": [{"id": "v1", "metadata": {"app": "http://mmif.clams.ai/apps/test/1.0", "contains": {}}, "annotations": []}]
+        }'''
+        m1 = Mmif(mmif_str)
+        m2 = Mmif(mmif_str)
+        # Set different timestamps
+        m1.views.get('v1').metadata.timestamp = datetime.now()
+        m2.views.get('v1').metadata.timestamp = datetime.now() + timedelta(seconds=10)
+        self.assertEqual(m1, m2)
+
     def test___getitem__(self):
         mmif_obj = Mmif(MMIF_EXAMPLES['everything'])
         self.assertIsInstance(mmif_obj['m1'], Document)
@@ -802,14 +885,14 @@ class TestView(unittest.TestCase):
         self.assertTrue(td1.properties.text_value == td1.text_value)
         self.assertNotEqual(td1.text_language, td2.text_language)
         self.assertEqual(english_text, td1.text_value)
-        self.assertEqual(td1, self.view_obj.annotations.get(td1.id))
+        self.assertEqual(td1, self.view_obj[td1.id])
         td3 = self.view_obj.new_textdocument(english_text, mime='plain/text')
         self.assertEqual(td1.text_value, td3.text_value)
         self.assertEqual(len(td1.properties), len(td3.properties) - 1)
 
     def test_parent(self):
         mmif_obj = Mmif(self.mmif_examples_json['everything'])
-        self.assertTrue(all(anno.parent == v.id for v in mmif_obj.views for anno in mmif_obj.get_view_by_id(v.id).annotations))
+        self.assertTrue(all(anno.parent == v.id for v in mmif_obj.views for anno in mmif_obj[v.id].annotations))
     
     def test_non_existing_parent(self):
         anno_obj = Annotation(FRACTIONAL_EXAMPLES['doc_only'])
@@ -820,20 +903,20 @@ class TestView(unittest.TestCase):
 
     def test_get_by_id(self):
         mmif_obj = Mmif(MMIF_EXAMPLES['everything'])
-        mmif_obj['m1']
-        mmif_obj['v4:td1']
+        mmif_obj.__getitem__('m1')
+        mmif_obj.__getitem__('v4:td1')
         with self.assertRaises(KeyError):
-            mmif_obj['m55']
+            mmif_obj.__getitem__('m55')
         with self.assertRaises(KeyError):
-            mmif_obj['v1:td1']
-        view_obj = mmif_obj['v4']
-        td1 = view_obj['v4:td1']
+            mmif_obj.__getitem__('v1:td1')
+        view_obj = mmif_obj.__getitem__('v4')
+        td1 = view_obj.__getitem__('v4:td1')
         self.assertEqual(td1.properties.mime, 'text/plain')
-        a1 = view_obj['v4:a1']
+        a1 = view_obj.__getitem__('v4:a1')
         self.assertEqual(a1.at_type, AnnotationTypes.Alignment)
         with self.assertRaises(KeyError):
-            view_obj['completely-unlikely-annotation-id']
-            
+            view_obj.__getitem__('completely-unlikely-annotation-id')
+
     def test_get_annotations(self):
         mmif_obj = Mmif(MMIF_EXAMPLES['everything'])
         # simple search by at_type
@@ -913,7 +996,8 @@ class TestView(unittest.TestCase):
         self.assertTrue(aview.has_error())
         self.assertTrue(isinstance(mmif_obj.get_last_error(), str))
         err_str = 'custom error as a single long string'
-        aview.metadata.error = err_str
+        aview.metadata.error = ErrorDict({'message': err_str})
+        print(aview.metadata.error)
         self.assertTrue(aview.has_error())
         self.assertTrue(isinstance(mmif_obj.get_last_error(), str))
         self.assertIn(err_str, mmif_obj.get_last_error())
@@ -1039,7 +1123,7 @@ class TestAnnotation(unittest.TestCase):
                     removed_prop_key, removed_prop_value = list(props.items())[-1]
                     props.pop(removed_prop_key)
                     new_mmif = Mmif(datum['json'])
-                    new_mmif.get_view_by_id(view_id).annotations[first_ann_id].add_property(removed_prop_key, removed_prop_value)
+                    new_mmif.get(view_id).annotations[first_ann_id].add_property(removed_prop_key, removed_prop_value)
                     self.assertEqual(json.loads(datum['string'])['views'][j],
                                      json.loads(new_mmif.serialize())['views'][j],
                                      f'Failed on {i}, {view_id}')
@@ -1236,9 +1320,9 @@ class TestDocument(unittest.TestCase):
         doc1.add_property('publisher', 'they')
         self.assertEqual(2, len(doc1._props_pending))
         mmif_roundtrip3 = Mmif(mmif_roundtrip2.serialize())
-        r0_v_anns = list(mmif_roundtrip3.views[r0_vid].get_annotations(AnnotationTypes.Annotation))
-        r1_v_anns = list(mmif_roundtrip3.views[r1_vid].get_annotations(AnnotationTypes.Annotation))
-        r2_v_anns = list(mmif_roundtrip3.views[r2_vid].get_annotations(AnnotationTypes.Annotation))
+        r0_v_anns = list(mmif_roundtrip3[r0_vid].get_annotations(AnnotationTypes.Annotation))
+        r1_v_anns = list(mmif_roundtrip3[r1_vid].get_annotations(AnnotationTypes.Annotation))
+        r2_v_anns = list(mmif_roundtrip3[r2_vid].get_annotations(AnnotationTypes.Annotation))
         # two props (`author` and `publisher`) are serialized to one `Annotation` objects
         self.assertEqual(1, len(r0_v_anns))  
         self.assertEqual(0, len(r1_v_anns))
@@ -1324,7 +1408,7 @@ class TestDocument(unittest.TestCase):
             mmif[f'doc{i+1}'].add_property('author', authors[i])
         mmif_roundtrip = Mmif(mmif.serialize())
         for i in range(1, 3):
-            cap_anns = list(mmif_roundtrip.views[f'v{i}'].get_annotations(AnnotationTypes.Annotation))
+            cap_anns = list(mmif_roundtrip[f'v{i}'].get_annotations(AnnotationTypes.Annotation))
             self.assertEqual(1, len(cap_anns))
             self.assertEqual(authors[i-1], cap_anns[0].get_property('author'))
             
@@ -1391,7 +1475,7 @@ class TestDocument(unittest.TestCase):
                     properties.pop(removed_prop_key)
                     try:
                         new_mmif = Mmif(datum['json'])
-                        new_mmif.get_document_by_id(document_id).add_property(removed_prop_key, removed_prop_value)
+                        new_mmif.get(document_id).add_property(removed_prop_key, removed_prop_value)
                         self.assertEqual(json.loads(datum['string']), json.loads(new_mmif.serialize()), f'Failed on {i}, {document_id}')
                     except ValidationError:
                         continue
@@ -1406,13 +1490,6 @@ class TestDataStructure(unittest.TestCase):
         self.datalist['v1'] = View({'id': 'v1'})
         self.datalist['v2'] = View({'id': 'v2'})
 
-    def test_getitem(self):
-        self.assertIs(self.mmif_obj['v1'], self.datalist['v1'])
-
-    def test_getitem_raises(self):
-        with self.assertRaises(KeyError):
-            _ = self.datalist['reserved_names']
-
     def test_append(self):
         self.assertTrue('v256' not in self.datalist._items)
         self.datalist.append(View({'id': 'v256'}))
@@ -1462,7 +1539,157 @@ class TestDataStructure(unittest.TestCase):
                 self.assertEqual("can't set item on a reserved name", ke.args[0])
 
     def test_get(self):
-        self.assertEqual(self.datalist['v1'], self.datalist.get('v1'))
+        # Test that get() returns the correct view and returns default for
+        # non-existent IDs
+        view = self.datalist.get('v1')
+        self.assertIsNotNone(view)
+        self.assertEqual('v1', view.id)
+
+        # Test default value
+        self.assertIsNone(self.datalist.get('nonexistent'))
+        self.assertEqual('default', self.datalist.get('nonexistent', 'default'))
+
+    # New tests for pythonic getters (#295)
+    def test_integer_indexing(self):
+        """Test that DataList supports integer indexing (list-like behavior)."""
+        # Positive indexing
+        first_view = self.datalist[0]
+        self.assertEqual('v1', first_view.id)
+
+        second_view = self.datalist[1]
+        self.assertEqual('v2', second_view.id)
+
+        # Negative indexing
+        last_view = self.datalist[-1]
+        self.assertEqual('v8', last_view.id)
+
+        second_to_last = self.datalist[-2]
+        self.assertEqual('v7', second_to_last.id)
+
+    def test_slice_indexing(self):
+        """Test that DataList supports slice indexing (list-like behavior)."""
+        # Basic slice
+        first_three = self.datalist[0:3]
+        self.assertEqual(3, len(first_three))
+        self.assertIsInstance(first_three, list)
+        self.assertEqual('v1', first_three[0].id)
+        self.assertEqual('v3', first_three[2].id)
+
+        # Slice with step
+        every_other = self.datalist[::2]
+        self.assertEqual(4, len(every_other))
+        self.assertEqual('v1', every_other[0].id)
+        self.assertEqual('v3', every_other[1].id)
+        self.assertEqual('v5', every_other[2].id)
+
+        # Slice from middle
+        middle = self.datalist[2:5]
+        self.assertEqual(3, len(middle))
+        self.assertEqual('v3', middle[0].id)
+        self.assertEqual('v4', middle[1].id)
+
+        # Empty slice
+        empty = self.datalist[10:20]
+        self.assertEqual(0, len(empty))
+
+    def test_string_indexing_raises_typeerror(self):
+        """Test that DataList raises TypeError for string indexing."""
+        # String indexing should raise TypeError
+        with self.assertRaises(TypeError) as cm:
+            _ = self.datalist['v1']
+        self.assertIn("list indices must be integers or slices", str(cm.exception))
+        self.assertIn("not str", str(cm.exception))
+
+        # Test with documents list too
+        with self.assertRaises(TypeError) as cm:
+            _ = self.mmif_obj.documents['m1']
+        self.assertIn("list indices must be integers or slices", str(cm.exception))
+
+    def test_get_deprecated_warning(self):
+        """Test that get() method raises DeprecationWarning."""
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            result = self.datalist.get('v1')
+
+            # Check that warning was raised
+            self.assertEqual(1, len(w))
+            self.assertTrue(issubclass(w[0].category, DeprecationWarning))
+            self.assertIn("deprecated", str(w[0].message).lower())
+            self.assertIn("2.0.0", str(w[0].message))
+
+            # But it should still work and return the view
+            self.assertIsNotNone(result)
+            self.assertEqual('v1', result.id)
+
+    def test_high_level_mmif_string_access(self):
+        """Test that high-level Mmif container accepts string IDs."""
+        # Mmif should accept string access (container behavior)
+        view = self.mmif_obj['v1']
+        self.assertEqual('v1', view.id)
+
+        doc = self.mmif_obj['m1']
+        self.assertEqual('m1', doc.id)
+
+        # Long-form annotation ID
+        ann = self.mmif_obj['v5:bb1']
+        self.assertIsNotNone(ann)
+
+    def test_high_level_view_string_access(self):
+        """Test that high-level View container accepts string IDs."""
+        view = self.mmif_obj['v4']
+
+        # View should accept string access (container behavior)
+        ann = view['v4:a1']
+        self.assertIsNotNone(ann)
+        self.assertEqual('v4:a1', ann.id)
+
+    def test_mmif_get_with_default(self):
+        """Test safe access on Mmif with default values."""
+        # Existing object
+        view = self.mmif_obj.get('v1')
+        self.assertIsNotNone(view)
+        self.assertEqual('v1', view.id)
+
+        # Non-existent object with default
+        result = self.mmif_obj.get('v999', default=None)
+        self.assertIsNone(result)
+
+        # Non-existent with custom default
+        default_value = "not found"
+        result = self.mmif_obj.get('v999', default=default_value)
+        self.assertEqual(default_value, result)
+
+    def test_mixed_access_patterns(self):
+        """Test that different access patterns can be used together."""
+        # Integer access on list
+        first_view = self.mmif_obj.views[0]
+
+        # String access on high-level container
+        specific_view = self.mmif_obj['v5']
+
+        # All should work
+        self.assertEqual('v1', first_view.id)
+        self.assertEqual('v5', specific_view.id)
+
+    def test_datalist_all_collections(self):
+        """Test that all DataList subclasses behave consistently."""
+        # ViewsList
+        view_by_int = self.mmif_obj.views[0]
+        view_by_container = self.mmif_obj[view_by_int.id]
+        self.assertEqual(view_by_int.id, view_by_container.id)
+
+        # DocumentsList
+        if len(self.mmif_obj.documents) > 0:
+            doc_by_int = self.mmif_obj.documents[0]
+            doc_by_container = self.mmif_obj[doc_by_int.id]
+            self.assertEqual(doc_by_int.id, doc_by_container.id)
+
+        # AnnotationsList
+        view = self.mmif_obj['v4']
+        if len(view.annotations) > 0:
+            ann_by_int = view.annotations[0]
+            ann_by_container = view[ann_by_int.id]
+            self.assertEqual(ann_by_int.id, ann_by_container.id)
 
     def test_update(self):
         other_contains = """{
